@@ -248,6 +248,11 @@ class CMA:
         when multi-variate gaussian distribution is updated."""
         return self._g
 
+    @property
+    def mean(self) -> np.ndarray:
+        """Mean Vector"""
+        return self._mean
+
     def reseed_rng(self, seed: int) -> None:
         self._rng.seed(seed)
 
@@ -396,7 +401,7 @@ class CMA:
         # Learning rate adaptation: https://arxiv.org/abs/2304.03473
         if self._lr_adapt:
             assert isinstance(old_mean, np.ndarray)
-            assert isinstance(old_sigma, float)
+            assert isinstance(old_sigma, (int, float))
             assert isinstance(old_Sigma, np.ndarray)
             assert isinstance(old_invsqrtC, np.ndarray)
             self._lr_adaptation(old_mean, old_sigma, old_Sigma, old_invsqrtC)
