@@ -17,6 +17,7 @@ Example:
   python3 tools/cmaes_visualizer.py --function himmelblau \
     --restart-strategy ipop --frames 500 --interval 10 --pop-per-frame 6
 """
+
 import argparse
 import math
 
@@ -74,12 +75,12 @@ color_dict = {
 bw = LinearSegmentedColormap("BlueWhile", color_dict)
 
 
-def himmelbleu(x1, x2):
+def himmelblau(x1, x2):
     return (x1**2 + x2 - 11.0) ** 2 + (x1 + x2**2 - 7.0) ** 2
 
 
-def himmelbleu_contour(x1, x2):
-    return np.log(himmelbleu(x1, x2) + 1)
+def himmelblau_contour(x1, x2):
+    return np.log(himmelblau(x1, x2) + 1)
 
 
 def quadratic(x1, x2):
@@ -123,8 +124,8 @@ if args.function == "quadratic":
     x2_lower_bound, x2_upper_bound = -4, 4
 elif args.function == "himmelblau":
     function_name = "Himmelblau function"
-    objective = himmelbleu
-    contour_function = himmelbleu_contour
+    objective = himmelblau
+    contour_function = himmelblau_contour
     global_minimums = [
         (3.0, 2.0),
         (-2.805118, 3.131312),
@@ -163,8 +164,8 @@ else:
 
 seed = args.seed
 bounds = np.array([[x1_lower_bound, x1_upper_bound], [x2_lower_bound, x2_upper_bound]])
-sigma = (x1_upper_bound - x2_lower_bound) / 5
-optimizer = CMA(mean=np.zeros(2), sigma=sigma, bounds=bounds, seed=seed)
+sigma0 = (x1_upper_bound - x2_lower_bound) / 5
+optimizer = CMA(mean=np.zeros(2), sigma=sigma0, bounds=bounds, seed=seed)
 solutions = []
 trial_number = 0
 rng = np.random.RandomState(seed)
@@ -188,7 +189,7 @@ def init():
         ax1.plot(m[0], m[1], "y*", ms=10)
         ax2.plot(m[0], m[1], "y*", ms=10)
 
-    # Plot contour of himmelbleu function
+    # Plot contour of himmelblau function
     x1 = np.arange(x1_lower_bound, x1_upper_bound, 0.01)
     x2 = np.arange(x2_lower_bound, x2_upper_bound, 0.01)
     x1, x2 = np.meshgrid(x1, x2)
@@ -196,13 +197,13 @@ def init():
     ax1.contour(x1, x2, contour_function(x1, x2), 30, cmap=bw)
 
 
-def get_next_popsize():
-    global optimizer, n_restarts, poptype, small_n_eval, large_n_eval
+def get_next_popsize_sigma():
+    global optimizer, n_restarts, poptype, small_n_eval, large_n_eval, sigma0
     if args.restart_strategy == "ipop":
         n_restarts += 1
         popsize = optimizer.population_size * inc_popsize
         print(f"Restart CMA-ES with popsize={popsize} at trial={trial_number}")
-        return popsize
+        return popsize, sigma0
     elif args.restart_strategy == "bipop":
         n_eval = optimizer.population_size * optimizer.generation
         if poptype == "small":
@@ -214,14 +215,16 @@ def get_next_popsize():
             poptype = "small"
             popsize_multiplier = inc_popsize**n_restarts
             popsize = math.floor(popsize0 * popsize_multiplier ** (rng.uniform() ** 2))
+            sigma = sigma0 * 10 ** (-2 * rng.uniform())
         else:
             poptype = "large"
             n_restarts += 1
             popsize = popsize0 * (inc_popsize**n_restarts)
+            sigma = sigma0
         print(
             f"Restart CMA-ES with popsize={popsize} ({poptype}) at trial={trial_number}"
         )
-        return
+        return popsize, sigma
     raise Exception("must not reach here")
 
 
@@ -232,7 +235,7 @@ def update(frame):
         solutions = []
 
         if optimizer.should_stop():
-            popsize = get_next_popsize()
+            popsize, sigma = get_next_popsize_sigma()
             lower_bounds, upper_bounds = bounds[:, 0], bounds[:, 1]
             mean = lower_bounds + (rng.rand(2) * (upper_bounds - lower_bounds))
             optimizer = CMA(
